@@ -1,6 +1,6 @@
 /***************************************************************************
  *   2007-2018 by Peter Semiletov                                          *
- *   peter.semiletov@gmail.com                                                           *
+ *   peter.semiletov@gmail.com                                             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -77,16 +77,19 @@ void CDocument::update_status()
 {
   if (! cursor_xy_visible)
      {
-      holder->l_status_bar->setText (charset);
+      holder->l_charset->setText (charset);
       return;
      }
- 
+
   int x = textEdit->textCursor().position() - textEdit->textCursor().block().position() + 1;
   int y = textEdit->textCursor().block().blockNumber() + 1;
 
-  holder->l_status_bar->setText (QString ("%1:%2 %3").arg (
+  holder->l_status_bar->setText (
+                                 QString ("%1:%2").arg (
                                  QString::number (y)).arg (
-                                 QString::number (x)).arg (charset));
+                                 QString::number (x)));
+
+  holder->l_charset->setText (charset);
 }
 
 
@@ -94,11 +97,11 @@ void CDocument::update_title (bool fullname)
 {
   if (! holder->parent_wnd)
      return;
-     
+
   QMainWindow *w = qobject_cast <QMainWindow *> (holder->parent_wnd);
 
   if (fullname)
-     w->setWindowTitle (file_name);
+      w->setWindowTitle (file_name);
   else
       w->setWindowTitle (QFileInfo (file_name).fileName());
 }
@@ -114,7 +117,7 @@ void CDocument::reload (const QString &enc)
 bool CDocument::open_file (const QString &fileName, const QString &codec)
 {
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
-  
+
   if (! tio)
       return false;
 
@@ -138,9 +141,11 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
 
   file_name = fileName;
 
+  holder->update_project (file_name);
+
   set_tab_caption (QFileInfo (file_name).fileName());
   set_hl();
-  
+
   set_markup_mode();
   textEdit->document()->setModified (false);
 
@@ -155,7 +160,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
              if (lt[0] == file_name) 
                 i.remove();
         }
-       
+
   return true;
 }
 
@@ -163,7 +168,7 @@ bool CDocument::open_file (const QString &fileName, const QString &codec)
 bool CDocument::save_with_name (const QString &fileName, const QString &codec)
 {
   CTio *tio = holder->tio_handler.get_for_fname (fileName);
-  
+
   if (! tio)
       return false;
 
@@ -173,8 +178,8 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
       tio->charset = codec;
 
   tio->data = textEdit->toPlainText();
-  
-   if (eol != "\n")
+
+  if (eol != "\n")
       tio->data.replace ("\n", eol);
 
   if (! tio->save (fileName))
@@ -185,22 +190,24 @@ bool CDocument::save_with_name (const QString &fileName, const QString &codec)
       return false;
      }
 
-if (! b_destroying_all)
- {
-  charset = tio->charset;
-  file_name = fileName;
+  if (! b_destroying_all)
+     {
+      charset = tio->charset;
+      file_name = fileName;
 
-  set_tab_caption (QFileInfo (file_name).fileName());
+      set_tab_caption (QFileInfo (file_name).fileName());
 
-  holder->log->log (tr ("%1 is saved").arg (file_name));
+      holder->log->log (tr ("%1 is saved").arg (file_name));
 
-  update_title (settings->value ("full_path_at_window_title", 1).toBool());
-  update_status();
+      update_title (settings->value ("full_path_at_window_title", 1).toBool());
+      update_status();
+
+      textEdit->document()->setModified (false);
+
+      holder->update_current_files_menu();
+      holder->update_project (file_name);
+     }
 
-  textEdit->document()->setModified (false);
-  
-  holder->update_current_files_menu();
- }
   return true;
 }
 
@@ -208,17 +215,17 @@ if (! b_destroying_all)
 CDocument::CDocument (QObject *parent): QObject (parent)
 {
   QString fname = tr ("new[%1]").arg (QTime::currentTime().toString ("hh-mm-ss"));
-  
+
   fnameswoexts.insert ("configure", "sh");
   fnameswoexts.insert ("install-sh", "sh");
-  
+
   markup_mode = "HTML";
   file_name = fname;
   cursor_xy_visible = true;
   charset = "UTF-8";
   text_to_search = "";
   position = 0;
-  
+
 #if defined(Q_OS_WIN) || defined(Q_OS_OS2)
 
   eol = "\r\n";
@@ -236,7 +243,7 @@ CDocument::~CDocument()
   if (file_name.endsWith (".notes") && textEdit->document()->isModified()) 
      save_with_name_plain (file_name);
   else
-  if (file_name.startsWith (holder->dir_config) && textEdit->document()->isModified()) 
+  if (file_name.startsWith (holder->dir_config) && textEdit->document()->isModified())
      save_with_name_plain (file_name);
   else
   if (textEdit->document()->isModified() && file_exists (file_name))
@@ -274,15 +281,14 @@ void CDocument::create_new()
 
   textEdit->doc = this;
 
-  textEdit->current_line_color = QColor (hash_get_val (global_palette, 
-                                         "cur_line_color", 
+  textEdit->current_line_color = QColor (hash_get_val (global_palette,
+                                         "cur_line_color",
                                          "#EEF6FF")).darker (settings->value ("darker_val", 100).toInt()).name();
 
   highlighter = NULL;
-
   int tab_index = holder->tab_widget->addTab (textEdit, file_name);
   tab_page = holder->tab_widget->widget (tab_index);
-   
+
   textEdit->setFocus (Qt::OtherFocusReason);
 }
 
@@ -316,12 +322,10 @@ CDox::~CDox()
         delete list.takeFirst();
 
   qstring_save (recent_list_fname, recent_files.join ("\n"));
-  
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+
+#if defined(Q_OS_LINUX)
   delete joystick;
 #endif
-#endif
 }
 
 
@@ -340,9 +344,9 @@ CDocument* CDox::create_new()
 
   doc->update_title (settings->value ("full_path_at_window_title", 1).toBool());
   doc->update_status();
-  
+
   update_current_files_menu();
-  
+
   return doc;
 }
 
@@ -441,80 +445,6 @@ bool CDocument::save_with_name_plain (const QString &fileName)
   return true;
 }
 
-/*
-QString CDocument::get_filename_at_cursor()
-{
-  if (textEdit->textCursor().hasSelection())
-     {
-      QFileInfo nf (file_name);
-      QDir cd (nf.absolutePath());
-      return cd.cleanPath (cd.absoluteFilePath(textEdit->textCursor().selectedText()));
-     }
-
-  QString s = textEdit->toPlainText();
-
-  QString x;
-
-  if (markup_mode == "LaTeX")
-     {
-      int pos = textEdit->textCursor().position();
-
-      int end = s.indexOf ("}", pos);
-      if (end == -1)
-         return x;
-
-      int start = s.lastIndexOf ("{", pos);
-      if (start == -1)
-         return x;
-
-      x = s.mid (start + 1, end - (start + 1));
-     
-      QFileInfo inf (file_name);
-      QDir cur_dir (inf.absolutePath());
-         
-      QString result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
-      if (file_exists (result))
-         return result;
-     
-      int i = x.lastIndexOf ("/");
-      if (i < 0)
-         i = x.lastIndexOf ("\\");
-     
-      if (i < 0)
-         return QString();
-
-      x = x.mid (i + 1);   
-     
-      result = cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
-      //qDebug() << "in cur dir: " << result;
-      return result;
-     }
-  else
- //   if (markup_mode == "HTML")
-   //fallback to HTML markup 
-     {
-      int pos = textEdit->textCursor().position();
-
-      int end = s.indexOf ("\"", pos);
-      if (end == -1)
-         return x;
-
-      int start = s.lastIndexOf ("\"", pos);
-      if (start == -1)
-         return x;
-
-      x = s.mid (start + 1, end - (start + 1));
-
-      if (x.startsWith("#"))
-         return x;
-
-      QFileInfo inf (file_name);
-      QDir cur_dir (inf.absolutePath());
-
-      return cur_dir.cleanPath (cur_dir.absoluteFilePath(x));
-     }
-}
-*/
 
 QString CDocument::get_filename_at_cursor()
 {
@@ -602,7 +532,6 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 {
   document = doc;
   casecare = true;
-  wrap = true;
   load_from_xml (fname);
 }
 
@@ -612,7 +541,6 @@ CSyntaxHighlighterQRegExp::CSyntaxHighlighterQRegExp (QTextDocument *parent, CDo
 CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTextDocument *parent, CDocument *doc, const QString &fname):
                                                                             CSyntaxHighlighter (parent, doc, fname)
 {
-  //qDebug() << "CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression";
   document = doc;
   load_from_xml (fname);
 }
@@ -622,6 +550,12 @@ CSyntaxHighlighterQRegularExpression::CSyntaxHighlighterQRegularExpression (QTex
 
 void CDocument::set_hl (bool mode_auto, const QString &theext)
 {
+  if (highlighter)
+     delete highlighter;
+
+  if (! settings->value ("hl_enabled", 1).toBool())
+      return;
+
   QString ext;
   
   if (mode_auto)
@@ -639,38 +573,21 @@ void CDocument::set_hl (bool mode_auto, const QString &theext)
      return;
 
   QString fname = holder->hls.value (ext);
-  
-//  qDebug() << "hl fname is " << fname;
-  
   if (fname.isEmpty() || ! file_exists (fname))
      return;
 
-  if (highlighter)
-     delete highlighter;
-  
 #if QT_VERSION >= 0x050000
-  
+
   if (settings->value ("qregexpsyntaxhl", 0).toBool())
      highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
   else
      highlighter = new CSyntaxHighlighterQRegularExpression (textEdit->document(), this, fname);
-  
+
 #else
-  
+
   highlighter = new CSyntaxHighlighterQRegExp (textEdit->document(), this, fname);
-  
-#endif  
-
-//  qDebug() << "highlighter->wrap: " << highlighter->wrap;
-  
-  if (textEdit->use_hl_wrap)
-     {
-      if (highlighter->wrap)
-         textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
-      else
-          textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
-     }
 
+#endif
 }
 
 
@@ -686,85 +603,43 @@ void CDox::apply_settings_single (CDocument *d)
 {
   int darker_val = settings->value ("darker_val", 100).toInt();
 
-/*  
-  QFont f;
-  f.fromString (settings->value ("editor_font_name", "Monospace").toString());
-  f.setPointSize (settings->value ("editor_font_size", "12").toInt());
-  d->textEdit->setFont (f);
-  d->textEdit->lineNumberArea->setFont (f);
-*/
-
   d->textEdit->setCursorWidth (settings->value ("cursor_width", 2).toInt());
   d->textEdit->setCenterOnScroll (settings->value ("center_on_scroll", true).toBool());
-  d->textEdit->use_hl_wrap = settings->value ("use_hl_wrap", true).toBool();
-  d->textEdit->wrap = settings->value ("word_wrap", true).toBool();
-    
+
   QString s_sel_back_color = hash_get_val (global_palette, "sel-background", "black");
   QString s_sel_text_color = hash_get_val (global_palette, "sel-text", "white");
-    
+
   d->textEdit->sel_text_color = QColor (s_sel_text_color).darker(darker_val).name(); 
   d->textEdit->sel_back_color = QColor (s_sel_back_color).darker(darker_val).name(); 
 
-    
-  if (! d->textEdit->use_hl_wrap)
-     {
-      if (d->textEdit->wrap)
-         d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
-      else
-          d->textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
-     }
-  
-  if (settings->value ("right_to_left", false).toBool())
-     d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignRight));
-  else
-     d->textEdit->document()->setDefaultTextOption (QTextOption (Qt::AlignLeft));
-    
- 
   d->textEdit->tab_sp_width = settings->value ("tab_sp_width", 8).toInt();
   d->textEdit->spaces_instead_of_tabs = settings->value ("spaces_instead_of_tabs", true).toBool();
 
   d->textEdit->setTabStopWidth (d->textEdit->tab_sp_width * d->textEdit->brace_width);
-  
+
   d->textEdit->setup_brace_width();
 
   d->textEdit->set_show_linenums (settings->value ("show_linenums", false).toBool());
   d->textEdit->set_show_margin (settings->value ("show_margin", false).toBool());
   d->textEdit->set_margin_pos (settings->value ("margin_pos", 72).toInt());
-  
-  
   d->textEdit->highlight_current_line = settings->value ("additional_hl", false).toBool();
   d->textEdit->hl_brackets = settings->value ("hl_brackets", false).toBool();
-
-  d->textEdit->current_line_color = QColor (hash_get_val (global_palette, "cur_line_color", "#EEF6FF")).darker (darker_val);
   d->textEdit->brackets_color = QColor (hash_get_val (global_palette, "brackets", "yellow")).darker (darker_val);
-  
+  d->textEdit->current_line_color = QColor (hash_get_val (global_palette, "cur_line_color", "#EEF6FF")).darker (darker_val);
+
   d->cursor_xy_visible = settings->value ("cursor_xy_visible", "2").toBool();
   d->textEdit->auto_indent = settings->value ("auto_indent", false).toBool();
 
   QString text_color = hash_get_val (global_palette, "text", "black");
   QString t_text_color = QColor (text_color).darker(darker_val).name(); 
-    
   d->textEdit->text_color = QColor (t_text_color);
 
   QString back_color = hash_get_val (global_palette, "background", "white");
-
   d->textEdit->margin_color = QColor (hash_get_val (global_palette, "margin_color", text_color)).darker(darker_val);
   d->textEdit->linenums_bg = QColor (hash_get_val (global_palette, "linenums_bg", back_color)).darker(darker_val);
 
-  //QString sel_back_color = hash_get_val (global_palette, "sel-background", "black");
-  //QString sel_text_color = hash_get_val (global_palette, "sel-text", "white");
-  //QString t_back_color = QColor (back_color).darker(darker_val).name(); 
-  //QString t_sel_text_color = QColor (sel_text_color).darker(darker_val).name(); 
-  //QString t_sel_back_color = QColor (sel_back_color).darker(darker_val).name(); 
-    
-  /*
-  QString sheet = QString ("QPlainTextEdit { color: %1 ; background-color: %2 ; selection-color: %3; selection-background-color: %4;}").arg (
-                           t_text_color).arg (
-                           t_back_color).arg (
-                           t_sel_text_color).arg (
-                           t_sel_back_color);
-                           
-  d->textEdit->setStyleSheet (sheet);*/
+  d->textEdit->set_word_wrap (settings->value ("word_wrap", true).toBool());
+
   d->textEdit->repaint();
   d->set_hl();
 }
@@ -789,17 +664,15 @@ void CDox::add_to_recent (CDocument *d)
   s += ",";
   s += d->charset;
   s += ",";
-  //s += QString ("%1").arg (d->textEdit->textCursor().position());
   s += QString::number (d->textEdit->textCursor().position());
   s += ",";
 
-  if (d->textEdit->lineWrapMode() == QPlainTextEdit::NoWrap)
+  if (! d->textEdit->get_word_wrap())
      s+="0";
   else 
       s+="1";
 
   recent_files.prepend (s);
-//  if (recent_files.size() > settings->value ("recent_list.max_items", 21).toInt())
   if (recent_files.size() > recent_list_max_items)
      recent_files.removeLast();
 }
@@ -834,15 +707,15 @@ CDocument* CDox::open_file_triplex (const QString &triplex)
   CDocument *d = open_file (sl[0], sl[1]);
   if (! d)
      return NULL;
-  
+
   d->goto_pos (sl[2].toInt());
 
   if (sl.size() >= 4)
      {
       if (sl[3] == "1")
-         d->textEdit->setLineWrapMode (QPlainTextEdit::WidgetWidth);
-      else    
-          d->textEdit->setLineWrapMode (QPlainTextEdit::NoWrap);
+         d->textEdit->set_word_wrap (true);
+      else
+         d->textEdit->set_word_wrap (false);
      }
 
   return d;
@@ -861,7 +734,7 @@ QString CDocument::get_triplex()
   s += QString::number (textEdit->textCursor().position());
   s += ",";
 
-  if (textEdit->lineWrapMode() == QPlainTextEdit::NoWrap)
+  if (! textEdit->get_word_wrap())
      s+="0";
   else 
       s+="1";
@@ -879,31 +752,6 @@ void CDocument::set_markup_mode()
   
   if (! t.isEmpty())
      markup_mode = t;
-
-/*
-  if (e == "htm" || e == "html")
-    markup_mode = "HTML";
-  else
-  if (e == "xhtml")
-    markup_mode = "XHTML";
-  else
-  if (e == "xml")
-    markup_mode = "Docbook";
-  else
-  if (e == "tex")
-    markup_mode = "LaTeX";
-  else
-  if (e == "lout")
-    markup_mode = "Lout";
-  else
-  if (e == "dokuwiki")
-    markup_mode = "DokuWiki";
-  else
-  if (e == "mediawiki")
-    markup_mode = "MediaWiki";
-  else
-  if (e == "md" || e == "markdown")
-     markup_mode = "Markdown";  */
 }
 
 
@@ -1010,8 +858,8 @@ CTEAEdit::CTEAEdit (QWidget *parent): QPlainTextEdit (parent)
   draw_margin = false;
   hl_brackets = false;
   auto_indent = false;
-  use_hl_wrap = false;
-  wrap = true;
+ // use_hl_wrap = false;
+  //wrap = true;
   tab_sp_width = 8;
   spaces_instead_of_tabs = true;
   
@@ -1039,23 +887,20 @@ CDox::CDox()
   markup_modes.insert ("mediawiki", "MediaWiki");
   markup_modes.insert ("md", "Markdown");
   markup_modes.insert ("markdown", "Markdown");
-  
+
   timer = new QTimer (this);
   timer->setInterval (100);
 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
   joystick = new CJoystick (0, this);
 
   if (joystick->initialized)
      {
       connect(timer, SIGNAL(timeout()), joystick, SLOT(read_joystick()));
-  
+
       if (settings->value ("use_joystick", "0").toInt())
-         timer->start();   
+         timer->start();
      }
-     
-#endif     
 #endif
 }
 
@@ -1090,10 +935,10 @@ QStringList CDocument::get_words()
         {
          cr.movePosition (QTextCursor::PreviousCharacter, QTextCursor::KeepAnchor);
          stext = cr.selectedText();
-        }  
-           
+        }
+
      if (! stext.isEmpty())
-        result.append (stext);     
+        result.append (stext);
     }
   while (cr.movePosition (QTextCursor::NextWord));
 
@@ -1107,7 +952,7 @@ QTextCharFormat tformat_from_style (const QString &fontstyle, const QString &col
   tformat.setForeground (QBrush (QColor (color).darker (darker_val)));
 
   if (fontstyle.isEmpty())
-     return tformat; 
+     return tformat;
 
   if (fontstyle.contains ("bold"))
       tformat.setFontWeight (QFont::Bold);
@@ -1131,7 +976,7 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
 {
 // qDebug() << "CSyntaxHighlighterQRegularExpression::load_from_xml ";
   
-  wrap = true;
+  //wrap = true;
   casecare = true;
   exts = "default";
   langs = "default";
@@ -1179,11 +1024,6 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                      QString s_xml_format = xml.attributes().value ("xml_format").toString();
                      if (! s_xml_format.isEmpty())
                         xml_format = s_xml_format.toInt();
-                    
-                     QString s_wrap = xml.attributes().value ("wrap").toString();
-                     if (! s_wrap.isEmpty())
-                        if (s_wrap == "0" || s_wrap == "false")
-                           wrap = false;
                         
                      QString s_casecare = xml.attributes().value ("casecare").toString();
                      if (! s_casecare.isEmpty())
@@ -1246,6 +1086,8 @@ void CSyntaxHighlighterQRegularExpression::load_from_xml (const QString &fname)
                         QString color = hash_get_val (global_palette, xml.attributes().value ("color").toString(), "darkBlue");
                         QTextCharFormat fmt = tformat_from_style (xml.attributes().value ("fontstyle").toString(), color, darker_val);
 
+                       // qDebug() << "attr_type == item, attr_name == " << attr_name; 
+
                         QRegularExpression rg = QRegularExpression (xml.readElementText().trimmed(), pattern_opts);
                         if (! rg.isValid())
                            qDebug() << "! valid " << rg.pattern();
@@ -1342,8 +1184,6 @@ void CSyntaxHighlighterQRegularExpression::highlightBlock (const QString &text)
          m_start = commentStartExpression.match (text, startIndex + commentLength);
          startIndex = m_start.capturedStart(); 
         }
-
-//   qDebug() << "2";
 }
 
 #endif
@@ -1394,10 +1234,10 @@ void CSyntaxHighlighterQRegExp::load_from_xml (const QString &fname)
 
                  if (attr_name == "options")
                     {
-                     QString s_wrap = xml.attributes().value ("wrap").toString();
+                    /* QString s_wrap = xml.attributes().value ("wrap").toString();
                      if (! s_wrap.isEmpty())
                         if (s_wrap == "0" || s_wrap == "false")
-                           wrap = false;
+                           wrap = false;*/
 
                      QString s_casecare = xml.attributes().value ("casecare").toString();
                      if (! s_casecare.isEmpty())
@@ -2793,8 +2633,7 @@ void CSyntaxHighlighter::highlightBlock (const QString &text)
 }
 */
 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
 bool CDox::event (QEvent *ev)
 {
 
@@ -2841,5 +2680,36 @@ void CDox::handle_joystick_event (CJoystickAxisEvent *event)
       d->textEdit->setTextCursor (cr);
      } 
 }    
+
 #endif
-#endif
+
+
+void CDox::update_project (const QString &fileName)
+{
+  if (file_get_ext (fileName) == "teaproject")
+    {
+     fname_current_project = fileName;
+     hash_project.clear();
+     hash_project = hash_load_keyval (fileName);
+    }
+}
+
+
+void CTEAEdit::set_word_wrap (bool wrap)
+{
+  if (wrap)
+     setWordWrapMode (QTextOption::WrapAtWordBoundaryOrAnywhere);    
+  else
+     setWordWrapMode (QTextOption::NoWrap);    
+     
+   
+}
+
+bool CTEAEdit::get_word_wrap()
+{
+  if (wordWrapMode() == QTextOption::WrapAtWordBoundaryOrAnywhere)   
+     return true;
+  else
+     return false;
+   
+}
