@@ -48,18 +48,16 @@ code from qwriter:
 #include <QRegularExpression>
 #endif
 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
 #include "myjoystick.h"
 #endif
-#endif
 
 #include "logmemo.h"
 #include "tio.h"
 #include "todo.h"
 
 
-class LineNumberArea;
+//class LineNumberArea;
 class CDox;
 class CDocument;
 
@@ -67,16 +65,16 @@ class CDocument;
 class CTEAEdit: public QPlainTextEdit
 {
   Q_OBJECT
-  
+
 public:
 
-  QString indent_val;  
+  QString indent_val;
   QList <QTextEdit::ExtraSelection> extraSelections;
   QTextEdit::ExtraSelection brace_selection;
-  
+
   QPoint rect_sel_start; //rect selection
   QPoint rect_sel_end;   //rect selection
- 
+
   CDocument *doc; //uplink
 
   QColor current_line_color;
@@ -94,9 +92,9 @@ public:
   bool hl_brackets;
   bool draw_margin;
   bool draw_linenums;
-  
-  bool use_hl_wrap;
-  bool wrap;
+
+ // bool use_hl_wrap;
+ // bool wrap;
 
   bool auto_indent;
   bool spaces_instead_of_tabs;
@@ -113,6 +111,9 @@ public:
   void set_margin_pos (int mp);
   void set_hl_cur_line (bool enable);
   void set_hl_brackets (bool enable);
+  
+  void set_word_wrap (bool wrap);
+  bool get_word_wrap();
 
   void indent();
   void un_indent();
@@ -129,30 +130,30 @@ public:
   void rect_sel_cut (bool just_del = false);
 
   void braceHighlight();
-  
+
   void lineNumberAreaPaintEvent(QPaintEvent *event);
   int lineNumberAreaWidth();
 
   Q_INVOKABLE bool has_rect_selection();
-  
+
 
 protected:
 
   bool canInsertFromMimeData (const QMimeData *source);
   void insertFromMimeData (const QMimeData *source);
-  
-  QMimeData* createMimeDataFromSelection(); 
+
+  QMimeData* createMimeDataFromSelection();
 
   void paintEvent(QPaintEvent *event);
-  void keyPressEvent (QKeyEvent *event);    
+  void keyPressEvent (QKeyEvent *event);
   void resizeEvent(QResizeEvent *event);
-  
+
 public slots:
 
   void updateLineNumberAreaWidth (int newBlockCount);
   void cb_cursorPositionChanged();
   void updateLineNumberArea (const QRect &, int);
-  
+
   void slot_selectionChanged();
 };
 
@@ -160,21 +161,20 @@ public slots:
 class CSyntaxHighlighter: public QSyntaxHighlighter
 {
 public:
- 
+
   CSyntaxHighlighter (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
- 
+
   CDocument *document;
   bool casecare;
-  bool wrap;
-  
+
   int xml_format;
-  
+
   QString exts;
   QString langs;
-    
+
   QString cm_mult;
   QString cm_single;
- 
+
   QTextCharFormat singleLineCommentFormat;
   QTextCharFormat multiLineCommentFormat;
 };
@@ -197,14 +197,14 @@ public:
         };
 
   QRegExp commentStartExpression;
-  QRegExp commentEndExpression;      
+  QRegExp commentEndExpression;
+
+  Qt::CaseSensitivity cs;
 
-  Qt::CaseSensitivity cs;  
-    
   CSyntaxHighlighterQRegExp (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
 
   QVector <HighlightingRule> highlightingRules;
- 
+
   void load_from_xml (const QString &fname);
 };
 
@@ -220,18 +220,18 @@ protected:
   void highlightBlock (const QString &text);
 
 public:
- 
+
   struct HighlightingRule
         {
          QRegularExpression pattern;
          QTextCharFormat format;
         };
-        
+
   QRegularExpression commentStartExpression;
   QRegularExpression commentEndExpression;
 
   QRegularExpression::PatternOptions pattern_opts;
-    
+
   CSyntaxHighlighterQRegularExpression (QTextDocument *parent = 0, CDocument *doc = 0, const QString &fname = "none");
 
   QVector <HighlightingRule> highlightingRules;
@@ -254,9 +254,9 @@ public:
   bool cursor_xy_visible;
 
   QHash <QString, QString> fnameswoexts;
-  
+
   QString eol;
-  
+
   CDox *holder;
   CSyntaxHighlighter *highlighter;
   CTEAEdit *textEdit;
@@ -303,49 +303,47 @@ class CDox: public QObject
 public:
 
   CTioHandler tio_handler;
+  CTodo todo;
+
+  QStringList recent_files;
 
   QString fname_current_session;
+  QString fname_current_project;
+  QString dir_config;
+  QString fname_crapbook;
+  QString markup_mode;
+  QString recent_list_fname;
 
   QHash <QString, QString> hls;
   QHash <QString, QString> markup_modes;
-  
+  QHash <QString, QString> hash_project;
+
   QLabel *l_status_bar;
-  QString dir_config;
+  QLabel *l_charset;
 
-  QString fname_crapbook;
+  QList <CDocument*> list;
 
-  CTodo todo;
-
-  QString markup_mode;
   QStatusBar *status_bar;
   CLogMemo *log;
-  QList <CDocument*> list;
   QMainWindow *parent_wnd;
   QTabWidget *tab_widget;
-
   QMenu *recent_menu;
-  QStringList recent_files;
-  QString recent_list_fname;
- 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
-  CJoystick *joystick;
-#endif 
-#endif
 
-  QTimer *timer; 
-  
+  QTimer *timer;
+
+#if defined(Q_OS_LINUX)
+  CJoystick *joystick;
+#endif
 
   CDox();
   ~CDox();
 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !!defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
   bool event (QEvent *ev);
   void handle_joystick_event (CJoystickAxisEvent *ev);
 #endif
-#endif 
-  
+
+  void update_project (const QString &fileName);
   void reload_recent_list();
   void add_to_recent (CDocument *d);
   void update_recent_menu();
@@ -358,18 +356,18 @@ public:
   Q_INVOKABLE CDocument* get_current();
   Q_INVOKABLE void close_by_idx (int i);
   Q_INVOKABLE void close_current();
-  
+
   Q_INVOKABLE void save_to_session (const QString &fileName);
   Q_INVOKABLE void load_from_session (const QString &fileName);
-  
+
   Q_INVOKABLE void apply_settings();
   Q_INVOKABLE void apply_settings_single (CDocument *d);
 
 public slots:
- 
+
   void open_recent();
   void open_current();
- 
+
 };
 
 
@@ -388,11 +386,11 @@ public:
 protected:
 
   void paintEvent (QPaintEvent *event)
-      {
-       code_editor->lineNumberAreaPaintEvent (event);
-      }
+       {
+        code_editor->lineNumberAreaPaintEvent (event);
+       }
 
 };
-  
+
 
 #endif
