@@ -3,10 +3,10 @@
 #ifndef MYJOYSTICK_H
 #define MYJOYSTICK_H
 
+#include <QtGlobal>
 #include <QObject>
 
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
 
 #include <iostream>
 #include <unistd.h>
@@ -17,8 +17,8 @@
 #include <QEvent>
 
 
-const QEvent::Type evtJoystickAxis = QEvent::Type(QEvent::User + 1);
-const QEvent::Type evtJoystickButton = QEvent::Type(QEvent::User + 2);
+const QEvent::Type evtJoystickAxis = QEvent::Type (QEvent::User + 1);
+const QEvent::Type evtJoystickButton = QEvent::Type (QEvent::User + 2);
 
 
 class CJoystickButtonEvent: public QEvent
@@ -27,7 +27,7 @@ public:
 
   uint button;
   bool pressed;
-    
+
   CJoystickButtonEvent (QEvent::Type type): QEvent (type), button (0), pressed (false) {}
 };
 
@@ -35,34 +35,34 @@ public:
 class CJoystickAxisEvent: public QEvent
 {
 public:
-  
+
   uint axis;
   qint16 value;
-    
-  CJoystickAxisEvent (QEvent::Type type): QEvent(type), axis (0), value (0) {}
+
+  CJoystickAxisEvent (QEvent::Type type): QEvent (type), axis (0), value (0) {}
 };
 
 
 class CJoystick: public QObject
 {
 Q_OBJECT
-    
+
 public:
 
-  QObject *receiver; //link to object that handle joystick events
+  QObject *receiver; //link to the object that handle joystick events
 
   int fd; //joystick file descriptor 
   uint id; //joystick id
-    
+
   QString description; //joystick text description
-  bool initialized; 
-       
+  bool initialized;
+
   uint number_of_axis;
   uint number_of_buttons;
 
   CJoystick (uint idn, QObject *upper_link);
-  ~CJoystick(); 
-    
+  ~CJoystick();
+
    void process_event (js_event e);
 
 public slots:
@@ -71,5 +71,4 @@ public slots:
 };
 
 #endif
-#endif //MAC
 #endif
