@@ -36,6 +36,7 @@
 #include <QTextBrowser>
 #include <QTranslator>
 #include <QProcess>
+#include <QProxyStyle>
 
 
 #ifdef USE_QML_STUFF
@@ -61,6 +62,98 @@
 #endif
 
 
+
+
+class MyProxyStyle: public QProxyStyle
+{
+public:
+
+ static bool b_altmenu;
+ static int cursor_blink_time;
+
+
+  int styleHint (StyleHint hint, const QStyleOption *option = 0,
+                 const QWidget *widget = 0, QStyleHintReturn *returnData = 0) const 
+                {
+                 if (hint == QStyle::SH_ItemView_ActivateItemOnSingleClick)
+                    return 0;
+         
+                 if (! b_altmenu && hint == QStyle::SH_MenuBar_AltKeyNavigation)
+                    return 0;
+                  
+                 return QProxyStyle::styleHint (hint, option, widget, returnData);
+                }
+     
+   MyProxyStyle (QStyle *style = 0);
+};
+
+
+
+#if QT_VERSION >= 0x050000
+class QStyleHints
+{
+public:
+  int cursorFlashTime() const 
+     {
+      return MyProxyStyle::cursor_blink_time;	
+     } 
+
+};
+#endif
+
+
+
+#ifdef USE_QML_STUFF
+class CQQuickWindow: public QQuickWindow
+{
+Q_OBJECT
+   
+public:
+
+  QString id;
+ 
+  CQQuickWindow (QWindow * parent = 0): QQuickWindow (parent) {}
+  ~CQQuickWindow() {}
+ 
+protected:
+
+  bool event (QEvent *event);
+};
+
+#endif
+
+
+#ifdef USE_QML_STUFF
+class CPluginListItem: public QObject
+{
+Q_OBJECT
+
+public:
+
+  QString id;
+  CQQuickWindow *window;
+ 
+  CPluginListItem (const QString &plid, CQQuickWindow *wnd);
+//  ~CPluginListItem() {}
+};
+#endif
+
+
+class CFSizeFName: public QObject
+{
+Q_OBJECT
+
+public:
+
+  qint64 size;
+  QString fname;
+
+  CFSizeFName (qint64 sz, const QString &fn):
+               size (sz),
+               fname (fn) {}
+};
+
+
 class CMarkupPair: public QObject
 {
 Q_OBJECT
@@ -148,7 +241,7 @@ Q_OBJECT
 public:
 
   rvln();
-  ~rvln();
+  ~rvln() {}
   
 #ifdef USE_QML_STUFF
   QQmlEngine *qml_engine;
@@ -271,17 +364,24 @@ public:
   QToolBar *tb_fman_dir;
   QLabel *l_fman_preview;
 
+  QLabel *l_charset;
+
   QLabel *l_status;
   QProgressBar *pb_status;
   QLineEdit *ed_spellcheck_path;
   QLineEdit *ed_aspellcheck_path;
   
   QCheckBox *cb_use_qregexpsyntaxhl;
+#if defined(Q_OS_LINUX)
   QCheckBox *cb_use_joystick;
+#endif
 
   QCheckBox *cb_right_to_left;
 
   QCheckBox *cb_wordwrap;
+//  QCheckBox *cb_colored_console;
+  
+  QCheckBox *cb_fif_at_toolbar;
   QCheckBox *cb_show_linenums;
   QCheckBox *cb_hl_current_line;
   QCheckBox *cb_show_margin;
@@ -295,6 +395,8 @@ public:
 
   QCheckBox *cb_session_restore;
   QCheckBox *cb_use_hl_wrap;
+  QCheckBox *cb_hl_enabled;
+
   QCheckBox *cb_hl_brackets;
   QCheckBox *cb_auto_indent;
   QCheckBox *cb_spaces_instead_of_tabs;
@@ -338,7 +440,10 @@ public slots:
 /*************************
 main window callbacks
 *************************/
- 
+
+  void logmemo_double_click (const QString &txt);
+
+
   void repeat();
 
   void receiveMessage (const QString &msg);
@@ -361,6 +466,7 @@ main window callbacks
 
   void fman_unpack_zip();
   void fman_zip_info();
+ // void fman_pack_sel_dir();
 
 
   void fman_refresh();
@@ -447,6 +553,7 @@ main window callbacks
   void fn_insert_cpp();
   void fn_insert_c();
   void fn_insert_template_html5();
+  void fn_insert_template_tea();
 
   bool save();
   bool saveAs();
@@ -484,6 +591,17 @@ main window callbacks
 
   void edit_copy_current_fname();
 
+  void ide_run();
+  void ide_build();
+  void ide_clean();
+/*
+  void ide_ctags();
+
+  void ide_gtags();
+  void ide_global_definition();
+  void ide_global_references();
+*/
+  
   void fn_count();
   void fn_count_rx();
 
@@ -695,11 +813,9 @@ main window callbacks
 /*************************
 prefs window callbacks
 *************************/
-#if defined(Q_OS_UNIX)
-#if !defined (Q_OS_MAC) || !defined (Q_OS_MACOS)
+#if defined(Q_OS_LINUX)
   void cb_use_joystick_stateChanged (int state);
 #endif
-#endif
 
 //  void cmb_ui_langs_currentIndexChanged (const QString &text);
 
@@ -719,6 +835,10 @@ prefs window callbacks
   void slot_editor_fontname_changed (const QString &text);
   void slot_font_size_changed (int i);
 
+  void slot_logmemo_fontname_changed (const QString &text);
+  void slot_logmemo_font_size_changed (int i);
+
+
   void slot_app_font_size_changed (int i);
   void slot_style_currentIndexChanged (const QString &text);
 
@@ -745,6 +865,10 @@ main window widgets
 
   QMenu *fileMenu;
   QMenu *editMenu;
+
+  QMenu *menu_ide;
+
+
   QMenu *menu_cal;
 
   QMenu *menu_cal_add;
@@ -774,7 +898,7 @@ main window widgets
 #endif
 
   QMenu *menu_view_themes;
-  
+
   QMenu *menu_markup;
   QMenu *menu_functions;
   QMenu *menu_functions_case;
@@ -801,6 +925,8 @@ main window widgets
   QToolBar *fileToolBar;
   QToolBar *editToolBar;
   QToolBar *filesToolBar;
+  QToolBar *statusToolBar;
+  QToolBar *fifToolBar;
 
   QAction *act_labels;
 
@@ -866,6 +992,10 @@ prefs window widgets
   QFontComboBox *cmb_font_name;
   QSpinBox *spb_font_size;
 
+  QFontComboBox *cmb_logmemo_font_name;
+  QSpinBox *spb_logmemo_font_size;
+
+
   QFontComboBox *cmb_app_font_name;
   QSpinBox *spb_app_font_size;
 
@@ -1020,23 +1150,4 @@ prefs window widgets
 };
 
 
-#ifdef USE_QML_STUFF
-
-class CQQuickWindow: public QQuickWindow
-{
-Q_OBJECT
-   
-public:
-
-  QString id;
- 
-  CQQuickWindow (QWindow * parent = 0): QQuickWindow (parent) {}
- 
-protected:
-
-  bool event (QEvent *event);
-};
-
-#endif
-
 #endif
