@@ -48,7 +48,9 @@ DJVU read code taken fromdvutxt.c:
 #include <QXmlStreamReader>
 #include <QTextStream>
 #include <QDebug>
+#include <iostream>
 
+//FIXME: not good with cmake, cmake just use Qt5 here
 #ifdef POPPLER_ENABLE
 #if QT_VERSION >= 0x050000
 #include <poppler-qt5.h>
@@ -74,6 +76,47 @@ DJVU read code taken fromdvutxt.c:
 #include "tio.h"
 #include "utils.h"
 #include "tzipper.h"
+#include "textproc.h"
+
+
+QString extract_text_from_xml (const QString &string_data, const QStringList &tags)
+{
+  QString data;
+  QXmlStreamReader xml (string_data);
+
+  bool tt = false;
+
+  while (! xml.atEnd())
+        {
+         xml.readNext();
+
+         QString tag_name = xml.qualifiedName().toString().toLower();
+
+         foreach (QString ts, tags)
+                {
+                 if (xml.isStartElement() && tag_name == ts)
+                    tt = true;
+
+                 if (xml.isEndElement() && tag_name == ts) 
+                    tt = false; 
+                 }
+
+         if (tt && xml.isCharacters())
+            {
+             QString s = xml.text().toString();
+             if (! s.isEmpty())
+               {
+                data.append (s);
+                data.append("\n");
+               }
+             }
+        }
+
+   if (xml.hasError())
+      qDebug() << "xml parse error";
+
+  return data;
+}
 
 
 bool CTioPlainText::load (const QString &fname)
@@ -98,8 +141,8 @@ bool CTioPlainText::load (const QString &fname)
   else
   if (block.indexOf ('\r') != -1)
      eol = "\r";
-        
-/*  
+
+/*
    if (eol == "\n")
      qDebug() << "LF";
    if (eol == "\r\n")
@@ -152,26 +195,23 @@ bool CTioPlainText::save (const QString &fname)
 CTioHandler::CTioHandler()
 {
   default_handler = new CTioPlainText;
-  
+
   list.append (default_handler);
   list.append (new CTioGzip);
   list.append (new CTioXMLZipped);
-  list.append (new CTioODTSpecial);
+  list.append (new CTioODT);
   list.append (new CTioABW);
   list.append (new CTioFB2);
   list.append (new CTioRTF);
+  list.append (new CTioEpub);
 
 #ifdef POPPLER_ENABLE
-  
   list.append (new CTioPDF);
-    
-#endif    
+#endif
 
 #ifdef DJVU_ENABLE
-  
   list.append (new CTioDJVU);
-    
-#endif    
+#endif
 }
 
 
@@ -237,45 +277,16 @@ bool CTioABW::load (const QString &fname)
 {
   QString temp = qstring_load (fname);
 
-  data.clear();
-
-  QXmlStreamReader xml (temp);
-
-  bool tt = false;
-
-  while (! xml.atEnd())
-        {
-         xml.readNext();
-
-         QString tag_name = xml.qualifiedName().toString().toLower();
-
-         if (xml.isStartElement())
-             if (tag_name == "p")
-                tt = true;
-
-         if (xml.isEndElement())
-            if (tag_name == "p")
-               tt = false;
-
-         if (tt && xml.isCharacters())
-            {
-             QString s = xml.text().toString();
-             if (! s.isEmpty())
-                {
-                 data.append (s);
-                 data.append("\n");
-                }
-            }
-        }
-
-   if (xml.hasError())
-      qDebug() << "xml parse error";
+  QStringList tags;
+  tags.append ("p");
+  
+  data = extract_text_from_xml (temp, tags);
 
   return true;
 }
 
 
-bool CTioODTSpecial::load (const QString &fname)
+bool CTioODT::load (const QString &fname)
 {
   data.clear();
   
@@ -332,7 +343,7 @@ bool CTioODTSpecial::load (const QString &fname)
 }
 
 
-CTioODTSpecial::CTioODTSpecial()
+CTioODT::CTioODT()
 {
   ronly = true;
 
@@ -370,43 +381,17 @@ bool CTioXMLZipped::load (const QString &fname)
       source_fname = "word/document.xml";
       ts = "w:t";  
      }
+ 
   
   CZipper zipper;
   if (! zipper.read_as_utf8 (fname, source_fname))
-       return false;
-    
-  QXmlStreamReader xml (zipper.string_data);
-  
-  bool tt = false;
-  
-  while (! xml.atEnd()) 
-        {
-         xml.readNext();
-
-         QString tag_name = xml.qualifiedName().toString().toLower();
-         
-         if (xml.isStartElement()) 
-             if (tag_name == ts)
-                tt = true;
-              
-         if (xml.isEndElement()) 
-            if (tag_name == ts) 
-               tt = false; 
-
-         if (tt && xml.isCharacters())
-            {
-             QString s = xml.text().toString();
-             if (! s.isEmpty())
-               {
-                data.append (s);
-                data.append("\n");
-               }
-             }
-        } 
-    
-   if (xml.hasError()) 
-      qDebug() << "xml parse error";
+      return false;
+ 
+  QStringList tags;
+  tags.append (ts);
   
+  data = extract_text_from_xml (zipper.string_data, tags);
+ 
   return true;
 }
 
@@ -545,13 +530,13 @@ bool CTioFB2::load (const QString &fname)
              if (tag_name == "title")
                 {
                  title = false;
-                 data.append("\n");
+                 data.append ("\n");
                 }
 
              if (tag_name == "section")
                 {
                  section = false;
-                 data.append("\n");
+                 data.append ("\n");
                 }
              }
 
@@ -562,7 +547,7 @@ bool CTioFB2::load (const QString &fname)
                 {
                  data.append ("   ");
                  data.append (s);
-                 data.append("\n");
+                 data.append ("\n");
                 }
             }
         }
@@ -820,8 +805,6 @@ bool CTioPDF::load (const QString &fname)
 #endif
 
 
-
-
 #ifdef DJVU_ENABLE
 
 
@@ -852,8 +835,8 @@ void djvumsg_handle()
              return;
             }
                 
-        ddjvu_message_pop(ctx);
-       }
+         ddjvu_message_pop(ctx);
+        }
 }
 
 
@@ -897,21 +880,110 @@ bool CTioDJVU::load (const QString &fname)
   while (! ddjvu_document_decoding_done (doc))
         djvumsg_handle();
 
-
   int n = ddjvu_document_get_pagenum (doc);
   
   for (int i = 0; i < n; i++)
       dopage (i);
- 
-  
+   
   if (doc)
-    ddjvu_document_release(doc);
+    ddjvu_document_release (doc);
     
   if (ctx)
-    ddjvu_context_release(ctx);
+    ddjvu_context_release (ctx);
 
   data = temp_data_s;
   return true;
 }
 
 #endif
+
+
+CTioEpub::CTioEpub()
+{
+  ronly = true;
+
+  extensions.append ("epub");
+}
+
+
+bool CTioEpub::load (const QString &fname)
+{
+  data.clear();
+    
+  
+  //JlCompress zipfile;  
+  
+  QStringList html_files;
+    
+  QString source_fname;
+  QString ts;  
+  
+  
+  CZipper zipper;
+  if (! zipper.read_as_utf8 (fname, "META-INF/container.xml"))
+       return false;
+  
+  
+  QString opf_fname;
+  QString opf_dir;
+  
+  int start = zipper.string_data.indexOf ("full-path=\"");
+  int end = zipper.string_data.indexOf ("\"", start + 11);
+  
+  opf_fname = zipper.string_data.mid (start + 11, end - start - 11);
+  opf_dir = opf_fname.left (opf_fname.indexOf ("/"));
+   
+  //std::cout << opf_fname.toStdString() << std::endl;
+  //std::cout << opf_dir.toStdString() << std::endl;
+
+  //READ FILES LIST. PARSE OPF FILE
+  
+  if (! zipper.read_as_utf8 (fname, opf_fname))
+       return false;
+  
+  
+  
+  
+  QXmlStreamReader xml (zipper.string_data);
+  
+  bool tt = false;
+  
+  while (! xml.atEnd()) 
+        {
+         xml.readNext();
+
+         QString tag_name = xml.qualifiedName().toString().toLower();
+         if (tag_name == "item")
+            {
+             QString attr_href = xml.attributes().value ("href").toString();
+             QString ext = file_get_ext (attr_href);
+             if (ext == "html" || ext == "htm" || ext == "xml")
+                html_files.append (opf_dir + "/" + attr_href);
+             //std::cout << attr_href.toStdString() << std::endl;
+ 
+            }
+        } 
+    
+  if (xml.hasError()) 
+      qDebug() << "xml parse error";
+  
+
+
+  foreach (QString fn, html_files)
+         {
+          if (! zipper.read_as_utf8 (fname, fn))
+              return false;
+              
+          //QString t = strip_html (zipper.string_data);
+          QStringList tags;
+          tags.append ("p");
+         // tags.append ("h2");
+          
+          QString t = extract_text_from_xml (zipper.string_data, tags);
+          
+          data += t;
+          data += "\n";
+         }
+   
+  return true;
+}
