@@ -52,6 +52,8 @@ public:
 
   virtual bool load (const QString &fname) = 0;
   virtual bool save (const QString &fname) = 0;
+
+  virtual ~CTio() {};
 };
 
 
@@ -99,13 +101,24 @@ public:
 };
 
 
-class CTioODTSpecial: public CTioReadOnly
+class CTioEpub: public CTioReadOnly
 {
   Q_OBJECT
 
 public:
 
-  CTioODTSpecial();
+  CTioEpub();
+  bool load (const QString &fname);
+};
+
+
+class CTioODT: public CTioReadOnly
+{
+  Q_OBJECT
+
+public:
+
+  CTioODT();
   bool load (const QString &fname);
 };
 
