@@ -13,6 +13,29 @@ Peter Semiletov
 
 #include "utils.h"
 
+/* file utils */
+
+
+bool file_is_writable (const QString &fname)
+{
+  QFile f (fname);  
+  return f.isWritable();
+}
+
+
+bool file_is_readable (const QString &fname)
+{
+  QFile f (fname);  
+  return f.isReadable();
+}
+
+
+bool dir_exists (const QString &path)
+{
+  QDir d (path);
+  return d.exists();
+}
+
 
 bool file_exists (const QString &fileName)
 {
@@ -22,10 +45,56 @@ bool file_exists (const QString &fileName)
   return QFile::exists (fileName);
 }
 
-bool dir_exists (const QString &path)
+
+QString change_file_ext (const QString &s, const QString &ext)
 {
-  QDir d (path);
-  return d.exists();
+  int i = s.lastIndexOf (".");
+  if (i == -1)
+     return (s + "." + ext);
+  
+  
+  QString r (s);
+  r.truncate (++i);
+  
+  r.append (ext);
+  return r;
+}
+
+
+QString file_get_ext (const QString &file_name)
+{
+  if (file_name.isEmpty())
+      return QString();
+
+  int i = file_name.lastIndexOf (".");
+  if (i == -1)
+      return QString();
+
+  return file_name.mid (i + 1).toLower();
+}
+
+
+QStringList read_dir_entries (const QString &path)
+{
+  QDir dir (path);
+  return dir.entryList (QDir::AllEntries | QDir::NoDotAndDotDot);
+}
+
+
+/* io utils */
+
+
+bool qstring_save (const QString &fileName, const QString &data, const char *enc)
+{
+  QFile file (fileName);
+  if (! file.open (QFile::WriteOnly | QFile::Text))
+      return false;
+
+  QTextStream out (&file);
+  out.setCodec (enc);
+  out << data;
+
+  return true;
 }
 
 
@@ -51,12 +120,55 @@ QString qstring_load_first_line (const QString &fileName)
      return QString();
 
   QTextStream in(&file);
-  //in.setCodec (enc);
 
   return in.readLine();
 }
 
 
+QByteArray file_load (const QString &fileName)
+{
+  QFile file (fileName);
+  QByteArray b;
+
+  if (! file.open (QFile::ReadOnly))
+      return b;
+
+  b = file.readAll();
+  return b;
+}
+
+
+/* string/stringlist utils */
+
+QString string_between (const QString &source,
+                        const QString &sep1,
+                        const QString &sep2)
+{
+  QString result;
+  int pos1 = source.indexOf (sep1);
+  if (pos1 == -1)
+     return result;
+
+  int pos2 = source.indexOf (sep2, pos1 + sep1.size());
+  if (pos2 == -1)
+     return result;
+
+  pos1 += sep1.size();
+  
+  result = source.mid (pos1, pos2 - pos1);
+  return result;
+}
+
+
+bool char_is_bad (const QChar &c)
+{
+  if (! c.isNull() && ! c.isLetter())
+     return true;
+
+  return false;
+}
+
+
 void qstring_list_print (const QStringList &l)
 {
   foreach (QString s, l)
@@ -64,54 +176,51 @@ void qstring_list_print (const QStringList &l)
 }
 
 
-bool qstring_save (const QString &fileName, const QString &data, const char *enc)
+QStringList bytearray_to_stringlist (QList<QByteArray> a)
 {
-  QFile file (fileName);
-  if (! file.open (QFile::WriteOnly | QFile::Text))
-      return false;
+  QStringList r;
+  foreach (QByteArray i, a)
+          r.append (i.data());
 
-  QTextStream out (&file);
-  out.setCodec (enc);
-  out << data;
-
-  return true;
+  return r;
 }
 
 
-QStringList read_dir_entries (const QString &path)
+/* hash utils */
+
+QString hash_get_val (QHash<QString, QString> &h,
+                      const QString &key,
+                      const QString &def_val)
 {
-  QDir dir (path);
-  return dir.entryList (QDir::AllEntries | QDir::NoDotAndDotDot);
-}
-
-
-QString file_get_ext (const QString &file_name)
-{
-  if (file_name.isEmpty())
-      return QString();
-
-  int i = file_name.lastIndexOf (".");
-  if (i == -1)
-      return QString();
-
-  return file_name.mid (i + 1).toLower();
-}
-
-
-QHash <QString, QString> stringlist_to_hash (const QStringList &l)
-{
-  QHash <QString, QString> result;
-
-  if (l.empty())
-     return result;
-
-  foreach (QString s, l)
-          result.insert (s, s);
+  QString result = h.value (key);
+  if (result.isEmpty())
+     {
+      result = def_val;
+      h.insert (key, def_val);
+     }
 
   return result;
 }
 
 
+QString qstring_load_value (const QString &fileName, const QString &key, const QString &def)
+{
+  QHash <QString, QString> h = hash_load_keyval (fileName);
+  return hash_get_val (h, key, def);
+}
+
+
+QString hash_keyval_to_string (const QHash <QString, QString> &h)
+{
+  QStringList l;
+
+  foreach (QString s, h.keys())
+          l.prepend (s.append ("=").append (h.value (s)));
+
+  return l.join ("\n").trimmed();
+}
+
+
 QHash <QString, QString> hash_load (const QString &fname)
 {
   QHash<QString, QString> result;
@@ -144,6 +253,22 @@ QHash <QString, QString> hash_load_keyval (const QString &fname)
 }
 
 
+QHash <QString, QString> stringlist_to_hash (const QStringList &l)
+{
+  QHash <QString, QString> result;
+
+  if (l.empty())
+     return result;
+
+  foreach (QString s, l)
+          result.insert (s, s);
+
+  return result;
+}
+
+
+/* image utils */
+
 bool is_image (const QString &filename)
 {
   if (filename.isEmpty())
@@ -162,94 +287,6 @@ bool is_image (const QString &filename)
 }
 
 
-QString hash_keyval_to_string (const QHash <QString, QString> &h)
-{
-  QStringList l;
-
-  foreach (QString s, h.keys())
-          l.prepend (s.append ("=").append (h.value (s)));
-
-  return l.join ("\n").trimmed();
-}
-
-
-QString hash_get_val (QHash<QString, QString> &h,
-                      const QString &key,
-                      const QString &def_val)
-{
-  QString result = h.value (key);
-  if (result.isEmpty())
-     {
-      result = def_val;
-      h.insert (key, def_val);
-     }
-
-  return result;
-}
-
-
-QString string_between (const QString &source,
-                        const QString &sep1,
-                        const QString &sep2)
-{
-  QString result;
-  int pos1 = source.indexOf (sep1);
-  if (pos1 == -1)
-     return result;
-
-  int pos2 = source.indexOf (sep2, pos1 + sep1.size());
-  if (pos2 == -1)
-     return result;
-
-  pos1 += sep1.size();
-  
-  result = source.mid (pos1, pos2 - pos1);
-  return result;
-}
-
-
-QByteArray file_load (const QString &fileName)
-{
-  QFile file (fileName);
-  QByteArray b;
-
-  if (! file.open (QFile::ReadOnly))
-      return b;
-
-  b = file.readAll();
-  return b;
-}
-
-
-QString change_file_ext (const QString &s, const QString &ext)
-{
-  int i = s.lastIndexOf (".");
-  if (i == -1)
-     return (s + "." + ext);
-  
-  
-  QString r (s);
-  r.truncate (++i);
-  
-  r.append (ext);
-  return r;
-}
-
-
-bool file_is_writable (const QString &fname)
-{
-  QFile f (fname);  
-  return f.isWritable();
-}
-
-
-bool file_is_readable (const QString &fname)
-{
-  QFile f (fname);  
-  return f.isReadable();
-}
-
-
 QString get_insert_image (const QString &file_name, const QString &full_path, const QString &markup_mode)
 {
   if (! is_image (full_path))
@@ -284,6 +321,7 @@ QString get_insert_image (const QString &file_name, const QString &full_path, co
    return result;
 }
 
+/* class functions */
 
 void CFilesList::iterate (QFileInfo &fi)
 {
@@ -330,23 +368,3 @@ bool CFTypeChecker::check (const QString &fname)
 
   return result;
 }
-
-
-bool char_is_bad (const QChar &c)
-{
- 
- if (! c.isNull() && ! c.isLetter())
-     return true;
-  
-  return false;
-}
-
-
-QStringList bytearray_to_stringlist (QList<QByteArray> a)
-{
-  QStringList r;
-  foreach (QByteArray i, a)
-          r.append (i.data());
-
-  return r;
-}
